@@ -1,10 +1,10 @@
-# @(#)$Id: ModelHelper.pm 1166 2012-04-03 12:37:30Z pjf $
+# @(#)$Id: ModelHelper.pm 1181 2012-04-17 19:06:07Z pjf $
 
 package CatalystX::Usul::Plugin::Controller::ModelHelper;
 
 use strict;
 use warnings;
-use version; our $VERSION = qv( sprintf '0.6.%d', q$Rev: 1166 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.7.%d', q$Rev: 1181 $ =~ /\d+/gmx );
 
 use CatalystX::Usul::Constants;
 
@@ -26,10 +26,10 @@ sub close_footer {
    my ($self, $c) = @_; my $s = $c->stash;
 
    if ($s->{footer}->{state}) {
-      $self->can( q(set_cookies) )
-         and $self->set_cookie( $c, { name  => $s->{cookie_prefix}.q(_state),
-                                      key   => q(footer),
-                                      value => q(false) } );
+      $self->can( q(set_cookies) ) and $self->set_cookie( $c, {
+         name  => $s->{cookie_prefix}.q(_state),
+         key   => q(footer),
+         value => q(false) } );
       $s->{footer}->{state} = FALSE;
    }
 
@@ -81,10 +81,10 @@ sub open_footer {
    my ($self, $c) = @_; my $s = $c->stash;
 
    unless ($s->{footer}->{state}) {
-      $self->can( q(set_cookie) )
-         and $self->set_cookie( $c, { name  => $s->{cookie_prefix}.q(_state),
-                                      key   => q(footer),
-                                      value => q(true) } );
+      $self->can( q(set_cookie) ) and $self->set_cookie( $c, {
+         name  => $s->{cookie_prefix}.q(_state),
+         key   => q(footer),
+         value => q(true) } );
       $s->{footer}->{state} = TRUE;
    }
 
@@ -161,7 +161,7 @@ CatalystX::Usul::Plugin::Controller::ModelHelper - Convenience methods for commo
 
 =head1 Version
 
-0.6.$Revision: 1166 $
+0.7.$Revision: 1181 $
 
 =head1 Synopsis
 
